#!/usr/bin/env python
# -*- coding: utf-8 -*-
#

# file      : wind_languages.py
# project   : createbasepy
# copyright : (C) 2014 by Claude BULIN
#
# This file is part of createbasepy project
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; version 3.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA


import sys, os
try:
	from gi.repository import Gtk, GObject
except:
	print("GTK Not Availible")
	sys.exit(1)
from fconfig import FConfig
import Language_Init

# ListUpdateLangs[] = [ 'checkbutton_french", "checkbutton_english", ... ]
ListeSaveActive = []

language_liste = [
	[ "checkbutton_afrikaans",  "afrikaans",  "af" ],
	[ "checkbutton_albanian",   "albanian",   "sq" ],
	[ "checkbutton_arabic",     "arabic",     "ar" ],
	[ "checkbutton_belarusian", "belarusian", "be" ],
	[ "checkbutton_bulgarian",  "bulgarian",  "bg" ],
	[ "checkbutton_catalan",    "catalan",    "ca" ],
	[ "checkbutton_chinese",    "chinese",    "zh" ],
	[ "checkbutton_croatian",   "croatian",   "hr" ],
	[ "checkbutton_czech",      "czech",      "cs" ],
	[ "checkbutton_danish",     "danish",     "da" ],

	[ "checkbutton_dutch",      "dutch",      "nl" ],
	[ "checkbutton_english",    "english",    "en" ],
	[ "checkbutton_estonian",   "estonian",   "et" ],
	[ "checkbutton_filipino",   "filipino",   "tl" ],
	[ "checkbutton_finnish",    "finnish",    "fi" ],
	[ "checkbutton_french",     "french",     "fr" ],
	[ "checkbutton_galician",   "galician",   "gl" ],
	[ "checkbutton_german",     "german",     "de" ],
	[ "checkbutton_greek",      "greek",      "el" ],
	[ "checkbutton_hebrew",     "hebrew",     "iw" ],

	[ "checkbutton_hindi",      "hindi",      "hi" ],
	[ "checkbutton_hungarian",  "hungarian",  "hu" ],
	[ "checkbutton_icelandic",  "icelandic",  "is" ],
	[ "checkbutton_indonesian", "indonesian", "id" ],
	[ "checkbutton_irish",      "irish",      "ga" ],
	[ "checkbutton_italian",    "italian",    "it" ],
	[ "checkbutton_japanese",   "japanese",   "ja" ],
	[ "checkbutton_korean",     "korean",     "ko" ],
	[ "checkbutton_latvian",    "latvian",    "lv" ],
	[ "checkbutton_lithuanian", "lithuanian", "lt" ],

	[ "checkbutton_macedonian", "macedonian", "mk" ],
	[ "checkbutton_malay",      "malay",      "ms" ],
	[ "checkbutton_maltese",    "maltese",    "mt" ],
	[ "checkbutton_norwegian",  "norwegian",  "no" ],
	[ "checkbutton_persian",    "persian",    "fa" ],
	[ "checkbutton_polish",     "polish",     "pl" ],
	[ "checkbutton_portuguese", "portuguese", "pt" ],
	[ "checkbutton_romanian",   "romanian",   "ro" ],
	[ "checkbutton_russian",    "russian",    "ru" ],
	[ "checkbutton_serbian",    "serbian",    "sr" ],

	[ "checkbutton_slovak",     "slovak",     "sk" ],
	[ "checkbutton_slovenian",  "slovenian",  "sl" ],
	[ "checkbutton_spanish",    "spanish",    "es" ],
	[ "checkbutton_swahili",    "swahili",    "sw" ],
	[ "checkbutton_swedish",    "swedish",    "sv" ],
	[ "checkbutton_thai",       "thai",       "th" ],
	[ "checkbutton_turkish",    "turkish",    "tr" ],
	[ "checkbutton_ukrainian",  "ukrainian",  "uk" ],
	[ "checkbutton_vietnamese", "vietnamese", "vi" ],
	[ "checkbutton_welsh",      "welsh",      "cy" ],

	[ "checkbutton_yiddish",    "yiddish",    "yi" ],
	]


# ListUpdateLangs[] = [ 'french", "english" ]
class wind_languages_init_list():
	def __init__( self ):
		ListeSaveActive[:] = []

	def init_list(self, p_ListUpdateLangs=[] ):
		# RetListLang = [ [ "checkbutton_welsh", "welsh", "cy" ], ... ]
		RetListLang = []
		for item in language_liste:
			if item[ 1 ] in p_ListUpdateLangs:
				ListeSaveActive.append( item[ 0 ].strip() )
				RetListLang.append( [ item[0], item[1], item[2] ] )
		return RetListLang

class wind_languages():

	def __init__( self, path="wind_languages.glade", Form=None, FuncUpdate=None ):

		# Add language support
		_ = Language_Init.Translator(FConfig).lang.gettext
		self._ = _
		self.CallFuncUpdate = FuncUpdate
		try:
			self.builder = Gtk.Builder()
			# Add language support from glade file
			self.builder.set_translation_domain("createbasepy")
			self.builder.add_from_file( FConfig.DATADIR + "/" + path )
		except:
			print("except from:Gtk.Builder() ")
			sys.exit(1)

		self.wind_languages=self.builder.get_object("wind_languages")
		self.wind_languages.set_transient_for( Form )

		dic={
			"on_wind_languages_delete_event": self.on_wind_languages_delete_event,
			"on_wind_languages_destroy_event": self.on_wind_languages_destroy_event,
			"on_button_applicate_clicked": self.on_button_applicate_clicked,
			"on_button_by_default_clicked": self.on_button_by_default_clicked,
			"on_button_cancel_clicked": self.on_button_cancel_clicked,
			"on_button_all_select_clicked": self.on_button_all_select_clicked,
			"on_button_all_deselect_clicked": self.on_button_all_deselect_clicked
		}
		self.builder.connect_signals(dic)
		self.label1=self.builder.get_object("label1")

		for item in ListeSaveActive:
			self.builder.get_object( item.strip() ).set_active( True )

		self.wind_languages.set_title("%s - Version %s" % (FConfig.__PACKAGE__, FConfig.__VERSION__))
		self.wind_languages.set_icon_from_file( FConfig.DATADIR + "/createbasepy.png" )
		self.wind_languages.show()

	def on_wind_languages_delete_event(self, widget, data=None):
		self.wind_languages.destroy()

	def on_wind_languages_destroy_event(self, widget, data=None):
		self.wind_languages.destroy()

	def on_button_by_default_clicked(self, widget, data=None):
		checkbutton_english = self.builder.get_object( "checkbutton_english" )
		checkbutton_french  = self.builder.get_object( "checkbutton_french" )
		checkbutton_german  = self.builder.get_object( "checkbutton_german" )
		checkbutton_italian = self.builder.get_object( "checkbutton_italian" )
		checkbutton_spanish = self.builder.get_object( "checkbutton_spanish" )

		bool_set_active = True

		if checkbutton_english.get_active() or checkbutton_french.get_active() or checkbutton_german.get_active() or \
			checkbutton_italian.get_active() or checkbutton_spanish.get_active():
			bool_set_active = False

		checkbutton_english.set_active( bool_set_active )
		checkbutton_french.set_active( bool_set_active )
		checkbutton_german.set_active( bool_set_active )
		checkbutton_italian.set_active( bool_set_active )
		checkbutton_spanish.set_active( bool_set_active )

	def on_button_cancel_clicked(self, widget, data=None):
		self.wind_languages.destroy()

	def on_button_all_select_clicked(self, widget, data=None):
		for item in language_liste:
			self.builder.get_object( item[ 0 ] ).set_active( True )

	def on_button_all_deselect_clicked(self, widget, data=None):
		for item in language_liste:
			self.builder.get_object( item[ 0 ] ).set_active( False )

	def on_button_applicate_clicked(self, widget, data=None):
		RetListe = []
		ListeSaveActive[:] = []
		for item in language_liste:
			label = self.builder.get_object( item[0].strip() )
			if label.get_active() == True:
				ListeSaveActive.append( item[0] )
				RetListe.append( [ item[0], item[1], item[2] ] )
		self.CallFuncUpdate( UpdateList=RetListe )
		self.wind_languages.destroy()


if __name__ == '__main__':
	wind = wind_languages()
	Gtk.main()









